@@ -5,16 +5,23 @@ from __future__ import print_function
 
 from __future__ import absolute_import
 import numpy as np
-import geojson
 import json
 from threedigrid.admin.breaches.models import Breaches
 from threedigrid.admin import constants
+from threedigrid.geo_utils import raise_import_exception
 from threedigrid.orm.base.encoder import NumpyEncoder
 from six.moves import range
 
+try:
+    import geojson
+except ImportError:
+    geojson = None
+
 
 class BreachesGeoJsonSerializer():
     def __init__(self, breaches=None, data=None, indent=None):
+        if geojson is None:
+            raise_import_exception('geojson')
         if breaches:
             assert isinstance(breaches, Breaches)
         self._data = data
