@@ -22,6 +22,14 @@ from threedigrid.admin.breaches.models import Breaches
 from threedigrid.admin.pumps.models import Pumps
 from threedigrid.admin.levees.models import Levees
 from threedigrid.admin.h5py_datasource import H5pyGroup
+
+try:
+    import asyncio_rpc # noqa
+    asyncio_rpc_support = True
+except ImportError:
+    asyncio_rpc_support = False
+
+
 from . import constants
 import six
 
@@ -38,7 +46,7 @@ class GridH5Admin(object):
         >>> ...
     """
 
-    def __init__(self, h5_file_path, file_modus='r'):
+    def __init__(self, h5_file_path, file_modus='r', set_props=False):
         """
         :param h5_file_path: path to the gridadmin file
         :param file_modus: mode with which to open the file
@@ -46,8 +54,28 @@ class GridH5Admin(object):
         """
 
         self.grid_file = h5_file_path
-        self.h5py_file = h5py.File(h5_file_path, file_modus)
-        self._set_props()
+        self.datasource_class = H5pyGroup
+        self.is_rpc = False
+
+        if ((type(h5_file_path) in (str, bytes) and
+             h5_file_path.startswith('rpc://'))):
+            if not asyncio_rpc_support:
+                raise Exception(
+                    "Please reinstall this package with threedigrid[rpc]")
+
+            from threedigrid.admin.rpc_datasource import H5RPCGroup, RPCFile
+            self.h5py_file = RPCFile(h5_file_path, file_modus)
+            self.datasource_class = H5RPCGroup
+            self._grid_kwargs = {}
+            self.is_rpc = True
+            self.has_1d = True
+            self.has_2d = True
+        else:
+            self.h5py_file = h5py.File(h5_file_path, file_modus)
+            set_props = True
+
+        if set_props:
+            self._set_props()
 
         self._grid_kwargs = {
             'has_1d': self.has_1d
@@ -55,43 +83,55 @@ class GridH5Admin(object):
 
     @property
     def grid(self):
+        if self.is_rpc:
+            raise Exception("RPC not available for grid")
         kwargs = self._grid_kwargs.copy()
         kwargs['n2dtot'] = self.get_from_meta('n2dtot')
         kwargs['dx'] = self.h5py_file['grid_coordinate_attributes']['dx'].value
         return Grid(
-            H5pyGroup(self.h5py_file, 'grid_coordinate_attributes'), **kwargs
+            self.datasource_class(
+                self.h5py_file, 'grid_coordinate_attributes'), **kwargs
         )
 
     @property
     def levees(self):
+        if self.is_rpc:
+            raise Exception("RPC no available for levees")
+
         return Levees(
-            H5pyGroup(self.h5py_file, 'levees'), **self._grid_kwargs)
+            self.datasource_class(
+                self.h5py_file, 'levees'), **self._grid_kwargs)
 
     @property
     def nodes(self):
         return Nodes(
-            H5pyGroup(self.h5py_file, 'nodes'), **self._grid_kwargs)
+            self.datasource_class(
+                self.h5py_file, 'nodes'), **self._grid_kwargs)
 
     @property
     def lines(self):
         return Lines(
-            H5pyGroup(self.h5py_file, 'lines'), **self._grid_kwargs)
+            self.datasource_class(
+                self.h5py_file, 'lines'), **self._grid_kwargs)
 
     @property
     def pumps(self):
         return Pumps(
-            H5pyGroup(self.h5py_file, 'pumps'), **self._grid_kwargs)
+            self.datasource_class(
+                self.h5py_file, 'pumps'), **self._grid_kwargs)
 
     @property
     def breaches(self):
         return Breaches(
-            H5pyGroup(self.h5py_file, 'breaches'), **self._grid_kwargs)
+            self.datasource_class(
+                self.h5py_file, 'breaches'), **self._grid_kwargs)
 
     @property
     def cells(self):
         # treated as nodes
         return Cells(
-            H5pyGroup(self.h5py_file, 'nodes'), **self._grid_kwargs)
+            self.datasource_class(
+                self.h5py_file, 'nodes'), **self._grid_kwargs)
 
     @property
     def revision_hash(self):
@@ -140,6 +180,11 @@ class GridH5Admin(object):
             output epsg code
         :return: numpy array of xy-min/xy-max pairs
         """
+        if self.is_rpc:
+            # Proxy function via RPC
+            return self.h5py_file.get_extent_subset(
+                subset_name, target_espg_code=target_epsg_code)
+
         attr_name = constants.SUBSET_NAME_H5_ATTR_MAP.get(subset_name.upper())
         extent = self.h5py_file.attrs.get(attr_name, None)
         if extent is None:
@@ -181,6 +226,11 @@ class GridH5Admin(object):
 
         """
         bbox = kwargs.get('extra_extent', [])
+        if self.is_rpc:
+            # Proxy function via RPC
+            return self.h5py_file.get_model_extent(
+                target_epsg_code=target_epsg_code, bbox=bbox)
+
         for k in constants.SUBSET_NAME_H5_ATTR_MAP.keys():
             sub_extent = self.get_extent_subset(
                 subset_name=k, target_epsg_code=target_epsg_code)
